@@ -26,11 +26,12 @@ use super::ui::{
     context::Context,
 };
 use crate::config::Termusic;
-use std::time::Instant;
-
+#[cfg(feature = "mpris")]
+use crate::souvlaki::mpris_handler;
 use log::error;
 use std::thread::sleep;
 use std::time::Duration;
+use std::time::Instant;
 
 pub struct App {
     pub config: Termusic,
@@ -78,6 +79,13 @@ impl App {
                 main_activity.run();
                 main_activity.update_download_progress();
                 main_activity.update_youtube_search();
+                // if let Ok(m) = main_activity.player.dbus_mpris.next() {
+                //     mpris_handler(m, &mut main_activity);
+                // }
+                #[cfg(feature = "mpris")]
+                if let Ok(m) = main_activity.player.rx.try_recv() {
+                    mpris_handler(m, &mut main_activity);
+                }
             }
             progress_interval += 1;
             if progress_interval >= 8 {
