@@ -36,10 +36,10 @@ mod view;
 mod youtube_options;
 
 // Locals
-use super::{Activity, Context, ExitReason, Status};
+use super::{Activity, Context, ExitReason};
 use crate::{
     config::{Termusic, MUSIC_DIR},
-    player::{Generic, Player},
+    player::GStreamer,
     song::Song,
     ui::activity::tageditor::TagEditorActivity,
 };
@@ -83,11 +83,11 @@ pub struct TermusicActivity {
     redraw: bool,
     path: PathBuf,
     tree: Tree,
-    player: Player,
+    pub player: GStreamer,
     queue_items: VecDeque<Song>,
     time_pos: u64,
-    status: Option<Status>,
-    current_song: Option<Song>,
+    pub status: Option<Status>,
+    pub current_song: Option<Song>,
     sender: Sender<TransferState>,
     receiver: Receiver<TransferState>,
     yanked_node_id: Option<String>,
@@ -106,6 +106,13 @@ pub enum MessageState {
     Hide,
 }
 
+#[derive(Clone, Copy)]
+pub enum Status {
+    Running,
+    Stopped,
+    Paused,
+}
+
 // TransferState is used to describe the status of download
 pub enum TransferState {
     Running, // indicates progress
@@ -146,7 +153,7 @@ impl Default for TermusicActivity {
             redraw: true, // Draw at first `on_draw`
             tree: Tree::new(Self::dir_tree(p, 3)),
             path: p.to_path_buf(),
-            player: Player::default(),
+            player: GStreamer::new(),
             queue_items: VecDeque::with_capacity(100),
             time_pos: 0,
             status: None,
@@ -182,17 +189,7 @@ impl TermusicActivity {
                     return;
                 }
                 self.status = Some(Status::Running);
-                if let Some(song) = self.queue_items.pop_front() {
-                    if let Some(file) = song.file() {
-                        self.player.queue_and_play(file);
-                    }
-                    self.queue_items.push_back(song.clone());
-                    self.current_song = Some(song);
-                    self.sync_queue();
-                    self.update_photo();
-                    self.update_progress_title();
-                    self.update_duration();
-                }
+                self.next_song();
             }
             Some(Status::Running | Status::Paused) => {}
             None => self.status = Some(Status::Stopped),
