@@ -32,17 +32,17 @@ use super::{
     COMPONENT_TREEVIEW,
 };
 use crate::{
-    player::Generic,
     song::Song,
     songtag::lrc::Lyric,
     ui::keymap::{
         MSG_KEY_BACKSPACE, MSG_KEY_CHAR_B, MSG_KEY_CHAR_CAPITAL_B, MSG_KEY_CHAR_CAPITAL_D,
         MSG_KEY_CHAR_CAPITAL_F, MSG_KEY_CHAR_CAPITAL_G, MSG_KEY_CHAR_CAPITAL_L,
-        MSG_KEY_CHAR_CAPITAL_Q, MSG_KEY_CHAR_CAPITAL_T, MSG_KEY_CHAR_D, MSG_KEY_CHAR_DASH,
-        MSG_KEY_CHAR_EQUAL, MSG_KEY_CHAR_F, MSG_KEY_CHAR_G, MSG_KEY_CHAR_H, MSG_KEY_CHAR_J,
-        MSG_KEY_CHAR_K, MSG_KEY_CHAR_L, MSG_KEY_CHAR_MINUS, MSG_KEY_CHAR_N, MSG_KEY_CHAR_P,
-        MSG_KEY_CHAR_PLUS, MSG_KEY_CHAR_R, MSG_KEY_CHAR_S, MSG_KEY_CHAR_T, MSG_KEY_CHAR_Y,
-        MSG_KEY_CTRL_H, MSG_KEY_ENTER, MSG_KEY_ESC, MSG_KEY_SHIFT_TAB, MSG_KEY_SPACE, MSG_KEY_TAB,
+        MSG_KEY_CHAR_CAPITAL_N, MSG_KEY_CHAR_CAPITAL_Q, MSG_KEY_CHAR_CAPITAL_T, MSG_KEY_CHAR_D,
+        MSG_KEY_CHAR_DASH, MSG_KEY_CHAR_EQUAL, MSG_KEY_CHAR_F, MSG_KEY_CHAR_G, MSG_KEY_CHAR_H,
+        MSG_KEY_CHAR_J, MSG_KEY_CHAR_K, MSG_KEY_CHAR_L, MSG_KEY_CHAR_MINUS, MSG_KEY_CHAR_N,
+        MSG_KEY_CHAR_P, MSG_KEY_CHAR_PLUS, MSG_KEY_CHAR_R, MSG_KEY_CHAR_S, MSG_KEY_CHAR_T,
+        MSG_KEY_CHAR_Y, MSG_KEY_CTRL_H, MSG_KEY_ENTER, MSG_KEY_ESC, MSG_KEY_SHIFT_TAB,
+        MSG_KEY_SPACE, MSG_KEY_TAB,
     },
 };
 use humantime::format_duration;
@@ -131,16 +131,19 @@ impl TermusicActivity {
                         self.update_progress();
                         None
                     } else {
-                        self.status = Some(Status::Stopped);
+                        // self.status = Some(Status::Stopped);
+                        self.update_progress();
                         None
                     },
                 // seek backward
                 (_, key) if key== &MSG_KEY_CHAR_B => if self.player.seek(-5).is_ok() {
                         self.time_pos -= 5;
+                        self.update_progress();
                         None
                     }
                     else {
                         self.status = Some(Status::Stopped);
+                        self.update_progress();
                         None
                     },
                 // adjust lyric delay 
@@ -294,9 +297,16 @@ impl TermusicActivity {
                 }
                 // Toggle skip
                 (_,key) if key==  &MSG_KEY_CHAR_N => {
-                    self.status = Some(Status::Stopped);
+                    // self.status = Some(Status::Stopped);
+                    self.next_song();
                     None
                 }
+                (_,key) if key==  &MSG_KEY_CHAR_CAPITAL_N => {
+                    // self.status = Some(Status::Stopped);
+                    self.previous_song();
+                    None
+                }
+
                 // shuffle
                 (COMPONENT_TABLE_QUEUE,key) if key==  &MSG_KEY_CHAR_S => {
                     self.shuffle();
@@ -776,4 +786,47 @@ impl TermusicActivity {
             self.redraw = true;
         }
     }
+
+    pub fn update_playing_song(&self) {
+        if let Some(song) = &self.current_song {
+            let name = song.name().unwrap_or("Unknown Song").to_string();
+            let tx = self.sender_message.clone();
+            thread::spawn(move || {
+                let _drop = tx.send(MessageState::Show(("Current Playing".to_string(), name)));
+                sleep(Duration::from_secs(5));
+                let _drop = tx.send(MessageState::Hide);
+            });
+        }
+    }
+
+    pub fn next_song(&mut self) {
+        if self.queue_items.is_empty() {
+            return;
+        }
+        if let Some(song) = self.queue_items.pop_front() {
+            if let Some(file) = song.file() {
+                self.player.queue_and_play(file);
+            }
+            self.queue_items.push_back(song.clone());
+            self.current_song = Some(song);
+            self.sync_queue();
+            self.update_photo();
+            self.update_progress_title();
+            self.update_duration();
+            self.update_playing_song();
+        }
+    }
+
+    pub fn previous_song(&mut self) {
+        if self.queue_items.is_empty() {
+            return;
+        }
+        if let Some(song) = self.queue_items.pop_back() {
+            self.queue_items.push_front(song);
+        }
+        if let Some(song) = self.queue_items.pop_back() {
+            self.queue_items.push_front(song);
+        }
+        self.next_song();
+    }
 }
