@@ -42,12 +42,6 @@ pub enum ExitReason {
     // EnterSetup,
 }
 
-pub enum Status {
-    Running,
-    Stopped,
-    Paused,
-}
-
 // -- Activity trait
 
 pub trait Activity {
